==> odb-api_0.17.6.orig.tar.xz: odb-api-0.17.6/eckit/src/eckit/io/Buffer.h <==
/*
 * (C) Copyright 1996-2017 ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

/// @author Baudouin Raoult
/// @author Tiago Quintino
/// @date   July 1996

#ifndef eckit_io_Buffer_h
#define eckit_io_Buffer_h

#include <string>

#include "eckit/eckit.h"

#include "eckit/memory/NonCopyable.h"

namespace eckit {

//----------------------------------------------------------------------------------------------------------------------

// A simple class to implement buffers

class Buffer : private NonCopyable {

public: // methods

    Buffer(size_t size);
    Buffer(const std::string& s);
    Buffer(const char*, size_t size);

    ~Buffer();

    operator char*()                 { return static_cast<char*>(buffer_); }
    operator const char*() const     { return static_cast<const char*>(buffer_); }

    operator void*()                 { return buffer_; }
    operator const void*() const     { return buffer_; }

    void* data() { return buffer_; }
    const void* data() const { return buffer_; }

    size_t size() const { return size_; }

    // void resize(size_t size);

    // void swap(Buffer& rhs);

protected: // methods

    void create();
    void destroy();

    void copy(const std::string& s);
    void copy(const char*,size_t size);

private: // members

    void*  buffer_;
    size_t size_;
};

//----------------------------------------------------------------------------------------------------------------------

} // namespace eckit

#endif

==> odb-api_0.18.0.orig.tar.xz: odb-api-0.18.0/eckit/src/eckit/io/Buffer.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

/// @author Baudouin Raoult
/// @author Tiago Quintino
/// @date   July 1996

#ifndef eckit_io_Buffer_h
#define eckit_io_Buffer_h

#include <string>

#include "eckit/eckit.h"

#include "eckit/memory/NonCopyable.h"

namespace eckit {

/// Simple class to implement static size memory buffers

class Buffer : private NonCopyable {
public:  // methods
    Buffer(size_t size);
    Buffer(const std::string& s);
    Buffer(const char*, size_t size);

    ~Buffer();

    operator char*() { return static_cast<char*>(buffer_); }
    operator const char*() const { return static_cast<const char*>(buffer_); }

    operator void*() { return buffer_; }
    operator const void*() const { return buffer_; }

    void* data() { return buffer_; }
    const void* data() const { return buffer_; }

    size_t size() const { return size_; }

    void zero();

    // void resize(size_t size);

    // void swap(Buffer& rhs);

protected:  // methods
    void create();
    void destroy();

    void copy(const std::string& s);
    void copy(const char*, size_t size);

private:  // members
    void* buffer_;
    size_t size_;
};

}  // namespace eckit

#endif
